@@ -138,9 +138,9 @@ fuzzy_keys <- function(keys) {
     ))
 
     # Message
-    message(crayon::magenta(
+    message(cli::col_magenta(
       "Found mispelled keys. Trying to map:",
-      paste("\n", names_fuzzy, "->", keys_match, collapse = "")
+      paste("\n", names_fuzzy, " -> ", keys_match, collapse = "")
     ))
 
     # Modify names
